[flashrom] [PATCH] Board enable for Asus P4B533-E

Michael Karcher flashrom at mkarcher.dialup.fu-berlin.de
Sat Feb 27 15:53:49 CET 2010


Signed-off-by: Michael Karcher <flashrom at mkarcher.dialup.fu-berlin.de>
---
Dear Walter,

this patch to flashrom adds support for the Asus P4B533-E board to
flashrom. While I understand that your system now works as it should, we
kindly ask you to consider trying this version of flashrom anyway.

If you just read an image and write back the same image, the only risk you
take is a power failure between erasing the BIOS chip and writing back
the same image. Testing would help us to know that the board specific
code is really correct for your board.

Regards,
  Michael Karcher

 board_enable.c |    5 ++++-
 1 files changed, 4 insertions(+), 1 deletions(-)

diff --git a/board_enable.c b/board_enable.c
index 4278b6d..0c957e2 100644
--- a/board_enable.c
+++ b/board_enable.c
@@ -872,7 +872,9 @@ static int intel_ich_gpio21_raise(const char *name)
 }
 
 /**
  * Suited for ASUS P4B266: socket478 + intel 845D + ICH2.
  */
 static int intel_ich_gpio22_raise(const char *name)
 {
@@ -1207,6 +1209,7 @@ struct board_pciid_enable board_pciid_enables[] = {
 	{0x1106, 0x1336, 0x1043, 0x80ed,  0x1106, 0x3288, 0x1043, 0x8249, NULL,          NULL,         NULL,          "ASUS",        "M2V-MX",                0,   via_vt823x_gpio5_raise},
 	{0x8086, 0x1a30, 0x1043, 0x8070,  0x8086, 0x244b, 0x1043, 0x8028, NULL,          NULL,         NULL,          "ASUS",        "P4B266",                0,   intel_ich_gpio22_raise},
 	{0x8086, 0x1A30, 0x1043, 0x8025,  0x8086, 0x244B, 0x104D, 0x80F0, NULL,          NULL,         NULL,          "ASUS",        "P4B266-LM",             0,   intel_ich_gpio21_raise},
+	{0x8086, 0x1A30, 0x1043, 0x8088,  0x8086, 0x24C3, 0x1043, 0x8089, NULL,          NULL,         NULL,          "ASUS",        "P4B533-E",              0,   intel_ich_gpio22_raise},
 	{0x8086, 0x2570, 0x1043, 0x80F2,  0x105A, 0x3373, 0x1043, 0x80F5, NULL,          NULL,         NULL,          "ASUS",        "P4P800-E Deluxe",       0,   intel_ich_gpio21_raise},
 	{0x10B9, 0x1541,      0,      0,  0x10B9, 0x1533,      0,      0, "^P5A$",       "asus",       "p5a",         "ASUS",        "P5A",                   0,   board_asus_p5a},
 	{0x10DE, 0x0030, 0x1043, 0x818a,  0x8086, 0x100E, 0x1043, 0x80EE, NULL,          NULL,         NULL,          "ASUS",        "P5ND2-SLI Deluxe",      0,   nvidia_mcp_gpio10_raise},
@@ -872,7 +872,9 @@ static int intel_ich_gpio21_raise(const char *name)
 
 /**
- * Suited for ASUS P4B266: socket478 + intel 845D + ICH2.
+ * Suited for:
+ * - ASUS P4B266: socket478 + intel 845D + ICH2.
+ * - Asus P4B533-E: socket478 + 845E + ICH4
  */
 static int intel_ich_gpio22_raise(const char *name)
-- 
1.6.5





More information about the flashrom mailing list